==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/Greengrass/DisassociateServiceRoleFromAccount.pm <==

package Paws::Greengrass::DisassociateServiceRoleFromAccount;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateServiceRoleFromAccount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/greengrass/servicerole');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Greengrass::DisassociateServiceRoleFromAccountResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Greengrass::DisassociateServiceRoleFromAccount - Arguments for method DisassociateServiceRoleFromAccount on Paws::Greengrass

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateServiceRoleFromAccount on the 
AWS Greengrass service. Use the attributes of this class
as arguments to method DisassociateServiceRoleFromAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateServiceRoleFromAccount.

As an example:

  $service_obj->DisassociateServiceRoleFromAccount(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateServiceRoleFromAccount in L<Paws::Greengrass>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/Greengrass/DisassociateServiceRoleFromAccount.pm <==

package Paws::Greengrass::DisassociateServiceRoleFromAccount;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateServiceRoleFromAccount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/greengrass/servicerole');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Greengrass::DisassociateServiceRoleFromAccountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Greengrass::DisassociateServiceRoleFromAccount - Arguments for method DisassociateServiceRoleFromAccount on L<Paws::Greengrass>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateServiceRoleFromAccount on the
L<AWS Greengrass|Paws::Greengrass> service. Use the attributes of this class
as arguments to method DisassociateServiceRoleFromAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateServiceRoleFromAccount.

=head1 SYNOPSIS

    my $greengrass = Paws->service('Greengrass');
    my $DisassociateServiceRoleFromAccountResponse =
      $greengrass->DisassociateServiceRoleFromAccount();

    # Results:
    my $DisassociatedAt =
      $DisassociateServiceRoleFromAccountResponse->DisassociatedAt;

# Returns a L<Paws::Greengrass::DisassociateServiceRoleFromAccountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/greengrass/>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateServiceRoleFromAccount in L<Paws::Greengrass>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
